pub struct AbstractValue {
    pub token: SignatureToken,
    pub abilities: AbilitySet,
}
This models a value on the stack or in the locals

Fields

token: SignatureToken

Represents the type of the value

abilities: AbilitySet

Represents the abilities of the value

Implementations

Create a new primitive AbstractValue given its type; the kind will be Copyable

Create a new reference AbstractValue given its type and kind

Create a new struct AbstractValue given its type and kind

Predicate on whether the type of the abstract value is generic – it is if it contains a type parameter.