Struct test_generation::abstract_state::CallGraph
source · [−]pub struct CallGraph { /* private fields */ }Implementations
sourceimpl CallGraph
impl CallGraph
pub fn new(max_function_handle_index: usize) -> Self
pub fn add_call(
&mut self,
caller: FunctionHandleIndex,
callee: FunctionHandleIndex
)
pub fn can_call(&self, my_index: FunctionHandleIndex) -> Vec<FunctionHandleIndex>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
pub fn max_calling_depth(&self, index: FunctionHandleIndex) -> usize
sourcepub fn call_depth(
&self,
caller: FunctionHandleIndex,
callee: FunctionHandleIndex
) -> Option<usize>
pub fn call_depth(
&self,
caller: FunctionHandleIndex,
callee: FunctionHandleIndex
) -> Option<usize>
None if recursive, Some(index) if non-recursive, and index is the length of the maximal call graph path originating at caller, and calling through callee.