pub struct InstantiableModule {
    pub module: CompiledModule,
    /* private fields */
}
During the generation of a bytecode sequence, specific instantiations may need to be made, that may not yet exist in the underlying module. Instead of mutating the underlying module in order to record these instantiations in the locals signature table, we instead build wrapper around the underlying module containing the type instantiations, and at the end materialize this updated signature pool into a module. We also need the ability to quickly determine if an instantiation has already been created, and if so, at which index. So this also keeps a reverse lookup table of instantiation to SignatureIndex.

Fields

module: CompiledModule

Implementations

If the instantiant is not in the instantiations table, this adds the instantiant to the instance_for_offset for table, and adds the index to the reverse lookup table. Returns the SignatureIndex for the instantiant.

If the instantiant is not in the struct_instantiations table, this adds the instantiant to the struct_instance_for_offset for table, and adds the index to the reverse lookup table. Returns the SignatureIndex for the instantiant.

If the instantiant is not in the function_instantiations table, this adds the instantiant to the func_instance_for_offset for table, and adds the index to the reverse lookup table. Returns the SignatureIndex for the instantiant.

If the instantiant is not in the field_instantiations table, this adds the instantiant to the field_instance_for_offset for table, and adds the index to the reverse lookup table. Returns the SignatureIndex for the instantiant.

Returns the type instantiation at index. Errors if the instantiation does not exist.

Returns the struct instantiation at index. Errors if the instantiation does not exist.

Returns the struct instantiation at index. Errors if the instantiation does not exist.

Returns the struct instantiation at index. Errors if the instantiation does not exist.

Consumes self, and adds the instantiations that have been built up to the underlying module, and returns the resultant compiled module.