Struct test_generation::borrow_graph::BorrowGraph
source · [−]pub struct BorrowGraph { /* private fields */ }Expand description
The BorrowGraph stores information sufficient to determine whether the instruction
of a bytecode instruction that interacts with references is memory safe.
Implementations
sourceimpl BorrowGraph
impl BorrowGraph
sourcepub fn new(num_locals: u8) -> BorrowGraph
pub fn new(num_locals: u8) -> BorrowGraph
Construct a new BorrowGraph given the number of locals it has
sourcepub fn fresh_partition(&mut self, n: (u16, Mutability)) -> Result<(), String>
pub fn fresh_partition(&mut self, n: (u16, Mutability)) -> Result<(), String>
Add a new partition to the graph containing nonce n
This operation may fail with an error a fresh partition ID
cannot be chosen.
sourcepub fn partition_mutability(
&self,
partition_id: u16
) -> Result<Mutability, String>
pub fn partition_mutability(
&self,
partition_id: u16
) -> Result<Mutability, String>
Determine whether a partition is mutable, immutable, or either. This operation may fail with an error if the given partition does not exist in the graph.