Struct test_generation::config::Args
source · [−]pub struct Args {
pub num_iterations: Option<u64>,
pub output_path: Option<String>,
pub seed: Option<String>,
pub num_threads: Option<u64>,
}Expand description
Command line arguments for the tool
Fields
num_iterations: Option<u64>The optional number of programs that will be generated. If not specified, program generation will run infinitely.
output_path: Option<String>Path where a serialized module should be saved.
If None, then the module will just be printed out.
seed: Option<String>The optional seed used for test generation.
num_threads: Option<u64>The optional number of threads to use for test generation.