Struct test_generation::control_flow_graph::BasicBlock
source · [−]pub struct BasicBlock { /* private fields */ }Expand description
This represents a basic block in a control flow graph
Implementations
sourceimpl BasicBlock
impl BasicBlock
pub fn new() -> BasicBlock
sourcepub fn get_locals_in(&self) -> &HashMap<usize, (AbstractValue, BorrowState)>
pub fn get_locals_in(&self) -> &HashMap<usize, (AbstractValue, BorrowState)>
Get the locals coming into the block
sourcepub fn get_locals_out(&self) -> &HashMap<usize, (AbstractValue, BorrowState)>
pub fn get_locals_out(&self) -> &HashMap<usize, (AbstractValue, BorrowState)>
Get the locals going out of the block
sourcepub fn set_instructions(&mut self, instructions: Vec<Bytecode>)
pub fn set_instructions(&mut self, instructions: Vec<Bytecode>)
Set the list of instructions that comprise the block