pub struct CFG { /* private fields */ }
A control flow graph

Implementations

Construct a control flow graph that contains empty basic blocks with set incoming and outgoing locals. Currently the control flow graph is acyclic.

Get a reference to all of the basic blocks of the CFG

Get a mutable reference to all of the basic blocks of the CFG

Retrieve the block IDs of all children of the given basic block block_id

Retrieve the number of children the given basic block block_id

Retrieve the block IDs of all parents of the given basic block block_id

Retrieve the number of parents the given basic block block_id

Decide the serialization order of the blocks in the CFG

Serialize the control flow graph into a sequence of instructions. Set the offsets of branch instructions appropriately.