macro_rules! function_instantiation_for_state {
($e: expr) => { ... };
}Expand description
Determine the proper type instantiation for function call in the current state.
macro_rules! function_instantiation_for_state {
($e: expr) => { ... };
}Determine the proper type instantiation for function call in the current state.