macro_rules! state_stack_is_castable {
($e1: expr) => { ... };
}Expand description
Determines if the type at the top of the abstract stack is castable to the given type.
macro_rules! state_stack_is_castable {
($e1: expr) => { ... };
}Determines if the type at the top of the abstract stack is castable to the given type.