Macro test_generation::with_ty_param
source · [−]macro_rules! with_ty_param {
(($is_exact: expr, $struct_inst_idx: expr) => $s_inst_idx:ident, $body:expr) => { ... };
}Expand description
A wrapper around type instantiation, that allows specifying an “exact” instantiation index, or if the instantiation should be inferred from the current state.