pub struct Subst {
    pub subst: HashMap<usize, SignatureToken>,
}
A substitution is a mapping from type formal index to the SignatureToken representing the type instantiation for that index.

Fields

subst: HashMap<usize, SignatureToken>

Implementations

NB that the position of arguments here matters. We can build a substitution if the instr_sig is a type parameter, and the stack_sig is a concrete type. But, if the instruction signature is a concrete type, but the stack signature is a type parameter, they cannot unify and no substitution is created.

Return the instantiation from the substitution that has been built.