Struct test_generation::abstract_state::AbstractValue
source · [−]pub struct AbstractValue {
pub token: SignatureToken,
pub abilities: AbilitySet,
}Expand description
This models a value on the stack or in the locals
Fields
token: SignatureTokenRepresents the type of the value
abilities: AbilitySetRepresents the abilities of the value
Implementations
sourceimpl AbstractValue
impl AbstractValue
sourcepub fn new_primitive(token: SignatureToken) -> AbstractValue
pub fn new_primitive(token: SignatureToken) -> AbstractValue
Create a new primitive AbstractValue given its type; the kind will be Copyable
sourcepub fn new_reference(
token: SignatureToken,
abilities: AbilitySet
) -> AbstractValue
pub fn new_reference(
token: SignatureToken,
abilities: AbilitySet
) -> AbstractValue
Create a new reference AbstractValue given its type and kind
sourcepub fn new_struct(token: SignatureToken, abilities: AbilitySet) -> AbstractValue
pub fn new_struct(token: SignatureToken, abilities: AbilitySet) -> AbstractValue
Create a new struct AbstractValue given its type and kind
pub fn new_value(token: SignatureToken, abilities: AbilitySet) -> AbstractValue
sourcepub fn is_generic(&self) -> bool
pub fn is_generic(&self) -> bool
Predicate on whether the type of the abstract value is generic – it is if it contains a type parameter.