pub struct BytecodeGenerator<'a> { /* private fields */ }
Generates a sequence of bytecode instructions. This generator has:

  • instructions: A list of bytecode instructions to use for generation
  • rng: A random number generator for uniform random choice of next instruction

Implementations

The BytecodeGenerator is instantiated with a seed to use with its random number generator.

Transition an abstract state, state to the next state and add the instruction to the bytecode sequence

Given a valid starting state abstract_state_in, generate a valid sequence of bytecode instructions such that abstract_state_out is reached.

Generate the body of a function definition given a set of starting locals and a target return signature. The sequence should contain at least target_min and at most target_max instructions.

Generate a sequence of instructions whose overall effect is to push a single value of type token on the stack, specifically without consuming any values that existed on the stack prior to the execution of the instruction sequence.