Module test_generation::summaries
source · [−]Structs
The Summary of a bytecode instruction contains a list of Preconditions
and a list of Effects.
Enums
Functions
Return the Summary for a bytecode instruction, instruction
Type Definitions
A Effect is a function that transforms on AbstractState to another
A Precondition is a boolean predicate on an AbstractState.